@@ -1,6 +1,6 @@
 from fwiffos.core import version
 from fwiffos.cli.sudo import LetUs
-from fwiffos.read.gsheets import GSheets
+from fwiffos.read.twitter import Twitter
 
 class Calculator(object):
 
@@ -23,7 +23,7 @@ class Commands(object):
         fs = FS()
         calc = Calculator()
         sudo = LetUs()
-        gsheets = GSheets()
+        twitter = Twitter()
         self._version = version
         self.__commands = {
             'ls': fs.ls,
@@ -31,7 +31,7 @@ class Commands(object):
             'mult': calc.multiply,
             'sudo': sudo.letus,
             'letus': sudo.letus,
-            'read': gsheets,
+            'read': twitter.tweet,
         }
 
     def exec(self):
